/**
 * File navigation.js.
 *
 * Handles toggling the navigation menu for small screens and enables TAB key
 * navigation support for dropdown menus.
 */
( function() {
    var writemag_secondary_container, writemag_secondary_button, writemag_secondary_menu, writemag_secondary_links, writemag_secondary_i, writemag_secondary_len;

    writemag_secondary_container = document.getElementById( 'writemag-secondary-navigation' );
    if ( ! writemag_secondary_container ) {
        return;
    }

    writemag_secondary_button = writemag_secondary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof writemag_secondary_button ) {
        return;
    }

    writemag_secondary_menu = writemag_secondary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof writemag_secondary_menu ) {
        writemag_secondary_button.style.display = 'none';
        return;
    }

    writemag_secondary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === writemag_secondary_menu.className.indexOf( 'nav-menu' ) ) {
        writemag_secondary_menu.className += ' nav-menu';
    }

    writemag_secondary_button.onclick = function() {
        if ( -1 !== writemag_secondary_container.className.indexOf( 'writemag-toggled' ) ) {
            writemag_secondary_container.className = writemag_secondary_container.className.replace( ' writemag-toggled', '' );
            writemag_secondary_button.setAttribute( 'aria-expanded', 'false' );
            writemag_secondary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            writemag_secondary_container.className += ' writemag-toggled';
            writemag_secondary_button.setAttribute( 'aria-expanded', 'true' );
            writemag_secondary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    writemag_secondary_links    = writemag_secondary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( writemag_secondary_i = 0, writemag_secondary_len = writemag_secondary_links.length; writemag_secondary_i < writemag_secondary_len; writemag_secondary_i++ ) {
        writemag_secondary_links[writemag_secondary_i].addEventListener( 'focus', writemag_secondary_toggleFocus, true );
        writemag_secondary_links[writemag_secondary_i].addEventListener( 'blur', writemag_secondary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function writemag_secondary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'writemag-focus' ) ) {
                    self.className = self.className.replace( ' writemag-focus', '' );
                } else {
                    self.className += ' writemag-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( writemag_secondary_container ) {
        var touchStartFn, writemag_secondary_i,
            parentLink = writemag_secondary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, writemag_secondary_i;

                if ( ! menuItem.classList.contains( 'writemag-focus' ) ) {
                    e.preventDefault();
                    for ( writemag_secondary_i = 0; writemag_secondary_i < menuItem.parentNode.children.length; ++writemag_secondary_i ) {
                        if ( menuItem === menuItem.parentNode.children[writemag_secondary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[writemag_secondary_i].classList.remove( 'writemag-focus' );
                    }
                    menuItem.classList.add( 'writemag-focus' );
                } else {
                    menuItem.classList.remove( 'writemag-focus' );
                }
            };

            for ( writemag_secondary_i = 0; writemag_secondary_i < parentLink.length; ++writemag_secondary_i ) {
                parentLink[writemag_secondary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( writemag_secondary_container ) );
} )();


( function() {
    var writemag_primary_container, writemag_primary_button, writemag_primary_menu, writemag_primary_links, writemag_primary_i, writemag_primary_len;

    writemag_primary_container = document.getElementById( 'writemag-primary-navigation' );
    if ( ! writemag_primary_container ) {
        return;
    }

    writemag_primary_button = writemag_primary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof writemag_primary_button ) {
        return;
    }

    writemag_primary_menu = writemag_primary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof writemag_primary_menu ) {
        writemag_primary_button.style.display = 'none';
        return;
    }

    writemag_primary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === writemag_primary_menu.className.indexOf( 'nav-menu' ) ) {
        writemag_primary_menu.className += ' nav-menu';
    }

    writemag_primary_button.onclick = function() {
        if ( -1 !== writemag_primary_container.className.indexOf( 'writemag-toggled' ) ) {
            writemag_primary_container.className = writemag_primary_container.className.replace( ' writemag-toggled', '' );
            writemag_primary_button.setAttribute( 'aria-expanded', 'false' );
            writemag_primary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            writemag_primary_container.className += ' writemag-toggled';
            writemag_primary_button.setAttribute( 'aria-expanded', 'true' );
            writemag_primary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    writemag_primary_links    = writemag_primary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( writemag_primary_i = 0, writemag_primary_len = writemag_primary_links.length; writemag_primary_i < writemag_primary_len; writemag_primary_i++ ) {
        writemag_primary_links[writemag_primary_i].addEventListener( 'focus', writemag_primary_toggleFocus, true );
        writemag_primary_links[writemag_primary_i].addEventListener( 'blur', writemag_primary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function writemag_primary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'writemag-focus' ) ) {
                    self.className = self.className.replace( ' writemag-focus', '' );
                } else {
                    self.className += ' writemag-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( writemag_primary_container ) {
        var touchStartFn, writemag_primary_i,
            parentLink = writemag_primary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, writemag_primary_i;

                if ( ! menuItem.classList.contains( 'writemag-focus' ) ) {
                    e.preventDefault();
                    for ( writemag_primary_i = 0; writemag_primary_i < menuItem.parentNode.children.length; ++writemag_primary_i ) {
                        if ( menuItem === menuItem.parentNode.children[writemag_primary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[writemag_primary_i].classList.remove( 'writemag-focus' );
                    }
                    menuItem.classList.add( 'writemag-focus' );
                } else {
                    menuItem.classList.remove( 'writemag-focus' );
                }
            };

            for ( writemag_primary_i = 0; writemag_primary_i < parentLink.length; ++writemag_primary_i ) {
                parentLink[writemag_primary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( writemag_primary_container ) );
} )();