<?php
/**
* Header options
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_header_options($wp_customize) {

    $wp_customize->add_section( 'writemag_section_header', array( 'title' => esc_html__( 'Header Options', 'writemag' ), 'panel' => 'writemag_main_options_panel', 'priority' => 120 ) );

    $wp_customize->add_setting( 'writemag_options[hide_tagline]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_tagline_control', array( 'label' => esc_html__( 'Hide Tagline', 'writemag' ), 'section' => 'writemag_section_header', 'settings' => 'writemag_options[hide_tagline]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_header_content]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_header_content_control', array( 'label' => esc_html__( 'Hide Header Content', 'writemag' ), 'section' => 'writemag_section_header', 'settings' => 'writemag_options[hide_header_content]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[logo_location]', array( 'default' => 'above-title', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_logo_location' ) );

    $wp_customize->add_control( 'writemag_logo_location_control', array( 'label' => esc_html__( 'Logo Location', 'writemag' ), 'description' => esc_html__('Select how you want to display the site logo with site title and tagline.', 'writemag'), 'section' => 'title_tagline', 'settings' => 'writemag_options[logo_location]', 'type' => 'select', 'choices' => array( 'beside-title' => esc_html__( 'Before Site Title and Tagline', 'writemag' ), 'above-title' => esc_html__( 'Above Site Title and Tagline', 'writemag' ) ), 'priority'   => 8 ) );


    $wp_customize->add_setting( 'writemag_options[hide_header_image]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_header_image_control', array( 'label' => esc_html__( 'Hide Header Image from Everywhere', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[hide_header_image]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[remove_header_image_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_remove_header_image_link_control', array( 'label' => esc_html__( 'Remove Link from Header Image', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[remove_header_image_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_header_image_details]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_header_image_details_control', array( 'label' => esc_html__( 'Hide both Title and Description from Header Image', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[hide_header_image_details]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_header_image_description]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_header_image_description_control', array( 'label' => esc_html__( 'Hide Description from Header Image', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[hide_header_image_description]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[header_image_custom_title]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_header_image_custom_title_control', array( 'label' => esc_html__( 'Header Image Custom Title', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[header_image_custom_title]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[header_image_custom_description]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_header_image_custom_description_control', array( 'label' => esc_html__( 'Header Image Custom Description', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[header_image_custom_description]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[header_image_destination]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_header_image_destination_control', array( 'label' => esc_html__( 'Header Image Destination URL', 'writemag' ), 'description' => esc_html__( 'Enter the URL a visitor should go when he/she click on the header image. If you did not enter a URL below, header image will be linked to the homepage of your website.', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[header_image_destination]', 'type' => 'text' ) );

   $wp_customize->add_setting( 'writemag_options[header_image_alt_text]', array( 'default' => get_bloginfo( 'name' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'writemag_header_image_alt_text_control', array( 'label' => esc_html__( 'Header Image Alt Text', 'writemag' ), 'section' => 'header_image', 'settings' => 'writemag_options[header_image_alt_text]', 'type' => 'text', ) );

}