<?php
/**
* Post Summaries options
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_post_summaries_options($wp_customize) {

    $wp_customize->add_section( 'writemag_section_posts_summaries', array( 'title' => esc_html__( 'Post Summaries Options', 'writemag' ), 'description' => esc_html__('To display your latest posts on your homepage, please set the "Your homepage displays" option to "Your latest posts." You can find this setting in your WordPress Dashboard by navigating to "Settings" -> "Reading" -> "Your homepage displays."', 'writemag'), 'panel' => 'writemag_main_options_panel', 'priority' => 175 ) );

    $wp_customize->add_setting( 'writemag_options[hide_posts_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_posts_heading_control', array( 'label' => esc_html__( 'Hide HomePage Posts Heading', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_posts_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[posts_heading]', array( 'default' => esc_html__( 'Recent Posts', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'writemag_posts_heading_control', array( 'label' => esc_html__( 'HomePage Posts Heading', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[posts_heading]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'posts_per_page', array( 'default' => get_option('posts_per_page'), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'writemag_posts_per_page_control', array( 'label' => esc_html__( 'Number of Posts per Page', 'writemag' ), 'description' => esc_html__('Set the maximum number of posts displayed on each blog page.', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'posts_per_page', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[post_style]', array( 'default' => 'compactview', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_post_style' ) );

    $wp_customize->add_control( 'writemag_post_style_control', array( 'label' => esc_html__( 'Posts Style', 'writemag' ), 'description' => esc_html__('Select the post style you want for home/categories/tags/archive/search-results pages.', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[post_style]', 'type' => 'select', 'choices' => array( 'compactview' => esc_html__('Compact', 'writemag'), 'fullview' => esc_html__('Full', 'writemag') ) ) );

    $wp_customize->add_setting( 'writemag_options[read_more_length]', array( 'default' => 20, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_read_more_length' ) );

    $wp_customize->add_control( 'writemag_read_more_length_control', array( 'label' => esc_html__( 'Auto Post Summary Length', 'writemag' ), 'description' => esc_html__('Enter the number of words need to display in the post summary. Default is 20 words.', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[read_more_length]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[show_read_more_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_show_read_more_button_control', array( 'label' => esc_html__( 'Show Read More Buttons on Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[show_read_more_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[read_more_text]', array( 'default' => esc_html__( 'Continue Reading', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'writemag_read_more_text_control', array( 'label' => esc_html__( 'Read More Text', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[read_more_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[hide_thumbnail_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_thumbnail_home_control', array( 'label' => esc_html__( 'Hide Featured Images from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_thumbnail_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_default_thumbnail_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_default_thumbnail_home_control', array( 'label' => esc_html__( 'Hide Default Images from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_default_thumbnail_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_post_title_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_post_title_home_control', array( 'label' => esc_html__( 'Hide Post Titles from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_post_title_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_post_author_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_post_author_home_control', array( 'label' => esc_html__( 'Hide Post Authors from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_post_author_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_posted_date_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_posted_date_home_control', array( 'label' => esc_html__( 'Hide Posted Dates from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_posted_date_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_comments_link_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_comments_link_home_control', array( 'label' => esc_html__( 'Hide Comment Links from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_comments_link_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_post_categories_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_post_categories_home_control', array( 'label' => esc_html__( 'Hide Post Categories from Posts Summaries', 'writemag' ), 'description' => esc_html__('This option is only for this post style : Full', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_post_categories_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[cat_links_text]', array( 'default' => esc_html__( 'Posted in:', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_cat_links_text_control', array( 'label' => esc_html__( 'Post Categories Pre Text', 'writemag' ), 'description' => esc_html__('Enter a text to display before post categories. Default text is "Posted in:".', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[cat_links_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[hide_post_tags_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_post_tags_home_control', array( 'label' => esc_html__( 'Hide Post Tags from Posts Summaries', 'writemag' ), 'description' => esc_html__('This option is only for this post style : Full', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_post_tags_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[tag_links_text]', array( 'default' => esc_html__( 'Tagged:', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_tag_links_text_control', array( 'label' => esc_html__( 'Post Tags Pre Text', 'writemag' ), 'description' => esc_html__('Enter a text to display before post tags. Default text is "Tagged:".', 'writemag'), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[tag_links_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[separate_taxonomies]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_separate_taxonomies_control', array( 'label' => esc_html__( 'Display Post Categories and Post Tags on Separate Lines', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[separate_taxonomies]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_post_snippet]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_post_snippet_control', array( 'label' => esc_html__( 'Hide Post Snippets from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[hide_post_snippet]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[display_full_post_content]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_display_full_post_content_control', array( 'label' => esc_html__( 'Display Full Post Content with Fullview Posts Style', 'writemag' ), 'section' => 'writemag_section_posts_summaries', 'settings' => 'writemag_options[display_full_post_content]', 'type' => 'checkbox', ) );

}