<?php
/**
* Search and 404 Page options
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_search_404_options($wp_customize) {

    $wp_customize->add_section( 'writemag_section_search_404', array( 'title' => esc_html__( 'Search and 404 Pages Options', 'writemag' ), 'panel' => 'writemag_main_options_panel', 'priority' => 340 ) );

    $wp_customize->add_setting( 'writemag_options[hide_search_results_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_search_results_heading_control', array( 'label' => esc_html__( 'Hide Search Results Heading', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[hide_search_results_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[search_results_heading]', array( 'default' => esc_html__( 'Search Results for:', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_search_results_heading_control', array( 'label' => esc_html__( 'Search Results Heading', 'writemag' ), 'description' => esc_html__( 'Enter a sentence to display before the search query.', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[search_results_heading]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[no_search_heading]', array( 'default' => esc_html__( 'Nothing Found', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_no_search_heading_control', array( 'label' => esc_html__( 'No Search Results Heading', 'writemag' ), 'description' => esc_html__( 'Enter a heading to display when no search results are found.', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[no_search_heading]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[no_search_results]', array( 'default' => esc_html__( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_no_search_results_control', array( 'label' => esc_html__( 'No Search Results Message', 'writemag' ), 'description' => esc_html__( 'Enter a message to display when no search results are found.', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[no_search_results]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'writemag_options[error_404_heading]', array( 'default' => esc_html__( 'Oops! That page can not be found.', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_error_404_heading_control', array( 'label' => esc_html__( '404 Error Page Heading', 'writemag' ), 'description' => esc_html__( 'Enter the heading for the 404 error page.', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[error_404_heading]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[error_404_message]', array( 'default' => esc_html__( 'It looks like nothing was found at this location. Maybe try one of the links below or a search?', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_error_404_message_control', array( 'label' => esc_html__( 'Error 404 Message', 'writemag' ), 'description' => esc_html__( 'Enter a message to display on the 404 error page.', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[error_404_message]', 'type' => 'textarea', ) );

    $wp_customize->add_setting( 'writemag_options[hide_404_search]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_404_search_control', array( 'label' => esc_html__( 'Hide Search Box from 404 Page', 'writemag' ), 'section' => 'writemag_section_search_404', 'settings' => 'writemag_options[hide_404_search]', 'type' => 'checkbox', ) );

}