<?php
/**
* Share Button options
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_share_buttons_options($wp_customize) {

    $wp_customize->add_section( 'writemag_section_share', array( 'title' => esc_html__( 'Share Buttons Options', 'writemag' ), 'panel' => 'writemag_main_options_panel', 'priority' => 260 ) );

    $wp_customize->add_setting( 'writemag_options[share_buttons_home_text]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );
    
    $wp_customize->add_control( new WriteMag_Customize_Static_Text_Control( $wp_customize, 'writemag_share_buttons_home_text_control', array(
        'label'       => esc_html__( 'Share Buttons on "Full" Posts Summaries', 'writemag' ),
        'section'     => 'writemag_section_share',
        'settings' => 'writemag_options[share_buttons_home_text]',
        'description' => '<hr/>'
    ) ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_buttons_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_buttons_home_control', array( 'label' => esc_html__( 'Hide Share Buttons from "Full" Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_buttons_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_text_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_text_home_control', array( 'label' => esc_html__( 'Hide Share Text from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_text_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[share_text_home]', array( 'default' => esc_html__( 'Share:', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_html', ) );

    $wp_customize->add_control( 'writemag_share_text_home_control', array( 'label' => esc_html__( 'Share Text for Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[share_text_home]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_twitter_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_twitter_home_control', array( 'label' => esc_html__( 'Hide X Share Button from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_twitter_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_facebook_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_facebook_home_control', array( 'label' => esc_html__( 'Hide Facebook Share Button from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_facebook_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_pinterest_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_pinterest_home_control', array( 'label' => esc_html__( 'Hide Pinterest Share Button from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_pinterest_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_linkedin_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_linkedin_home_control', array( 'label' => esc_html__( 'Hide Linkedin Share Button from Posts Summaries', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_linkedin_home]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'writemag_options[share_buttons_text]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );
    
    $wp_customize->add_control( new WriteMag_Customize_Static_Text_Control( $wp_customize, 'writemag_share_buttons_text_control', array(
        'label'       => esc_html__( 'Share Buttons on Single Posts', 'writemag' ),
        'section'     => 'writemag_section_share',
        'settings' => 'writemag_options[share_buttons_text]',
        'description' => '<hr/>'
    ) ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_buttons_control', array( 'label' => esc_html__( 'Hide Share Buttons from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_text]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_text_control', array( 'label' => esc_html__( 'Hide Share Text from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_text]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[share_text]', array( 'default' => esc_html__( 'Share:', 'writemag' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'writemag_share_text_control', array( 'label' => esc_html__( 'Share Text for Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[share_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_twitter]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_twitter_control', array( 'label' => esc_html__( 'Hide X Share Button from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_twitter]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_facebook]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_facebook_control', array( 'label' => esc_html__( 'Hide Facebook Share Button from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_facebook]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_pinterest]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_pinterest_control', array( 'label' => esc_html__( 'Hide Pinterest Share Button from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_pinterest]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_share_linkedin]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_share_linkedin_control', array( 'label' => esc_html__( 'Hide Linkedin Share Button from Single Posts', 'writemag' ), 'section' => 'writemag_section_share', 'settings' => 'writemag_options[hide_share_linkedin]', 'type' => 'checkbox', ) );

}