<?php
/**
* Social profiles options
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_header_social_profiles($wp_customize) {

    $wp_customize->add_section( 'writemag_section_social', array( 'title' => esc_html__( 'Social Links Options', 'writemag' ), 'panel' => 'writemag_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'writemag_options[social_buttons_location]', array( 'default' => 'secondary-menu', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_social_buttons_location' ) );

    $wp_customize->add_control( 'writemag_social_buttons_location_control', array( 'label' => esc_html__( 'Social + Search + Login/Logout Buttons Location', 'writemag' ), 'description' => esc_html__('Select where you want to display social buttons.', 'writemag'), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[social_buttons_location]', 'type' => 'select', 'choices' => array( 'primary-menu' => esc_html__( 'Primary Menu', 'writemag' ), 'secondary-menu' => esc_html__( 'Secondary Menu', 'writemag' ) ) ) );

    $wp_customize->add_setting( 'writemag_options[hide_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_social_buttons_control', array( 'label' => esc_html__( 'Hide Social + Search + Login/Logout Buttons', 'writemag' ), 'description' => esc_html__('If you checked this option, there is no any effect from these option: "Hide Search Button", "Show Login/Logout Button".', 'writemag'), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[hide_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[hide_search_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_hide_search_button_control', array( 'label' => esc_html__( 'Hide Search Button', 'writemag' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'writemag'), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[hide_search_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_checkbox', ) );

    $wp_customize->add_control( 'writemag_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button', 'writemag' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'writemag'), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'writemag_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_twitterlink_control', array( 'label' => esc_html__( 'X URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[threadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_threadslink_control', array( 'label' => esc_html__( 'Threads URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[threadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'writemag_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_vklink_control', array( 'label' => esc_html__( 'VK Link', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_githublink_control', array( 'label' => esc_html__( 'Github URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[mastodonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_mastodonlink_control', array( 'label' => esc_html__( 'Mastodon URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[mastodonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'writemag_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'writemag_sanitize_email' ) );

    $wp_customize->add_control( 'writemag_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'writemag_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'writemag_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'writemag' ), 'section' => 'writemag_section_social', 'settings' => 'writemag_options[rsslink]', 'type' => 'text' ) );

}