<?php
/**
* Css Classes Functions
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

// Category ids in post class
function writemag_category_id_class($classes) {
    global $post;
    foreach((get_the_category($post->ID)) as $category) {
        $classes[] = 'wpcat-' . $category->cat_ID . '-id';
    }
    return $classes;
}
add_filter('post_class', 'writemag_category_id_class');


// Adds custom classes to the array of body classes.
function writemag_body_classes( $classes ) {
    // Adds a class of group-blog to blogs with more than 1 published author.
    if ( is_multi_author() ) {
        $classes[] = 'writemag-group-blog';
    }

    if ( !(writemag_get_option('disable_loading_animation')) ) {
        $classes[] = 'writemag-animated writemag-fadein';
    }

    $classes[] = 'writemag-theme-is-active';

    if ( get_header_image() ) {
        $classes[] = 'writemag-header-image-active';
    }

    if ( has_custom_logo() ) {
        $classes[] = 'writemag-custom-logo-active';
    }

    $classes[] = 'writemag-layout-type-full';

    if ( is_singular() ) {
        if( is_single() ) {
            if ( writemag_get_option('featured_media_under_post_title') ) {
                $classes[] = 'writemag-single-media-under-title';
            }
        }
        if( is_page() ) {
            if ( writemag_get_option('featured_media_under_page_title') ) {
                $classes[] = 'writemag-single-media-under-title';
            }
        }
        if ( is_page_template() ) {
            if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
               $classes[] = 'writemag-layout-full-width';
            } else {
                $classes[] = 'writemag-layout-s1-c-s2';
            }
        } else {
            $classes[] = 'writemag-layout-s1-c-s2';
        }
    } else {
        if ( is_404() ) {
            $classes[] = 'writemag-layout-full-width';
        } else {
            $classes[] = 'writemag-layout-s1-c-s2';
        }
    }

    $classes[] = 'writemag-header-banner-active';

    if ( writemag_get_option('hide_tagline') ) {
        $classes[] = 'writemag-tagline-inactive';
    }

    if ( 'beside-title' === writemag_get_option('logo_location') ) {
        $classes[] = 'writemag-logo-beside-title';
    } elseif ( 'above-title' === writemag_get_option('logo_location') ) {
        $classes[] = 'writemag-logo-above-title';
    } else {
        $classes[] = 'writemag-logo-above-title';
    }

    if ( writemag_is_primary_menu_active() ) {
        $classes[] = 'writemag-primary-menu-active';
    } else {
        $classes[] = 'writemag-primary-menu-inactive';
    }
    $classes[] = 'writemag-primary-mobile-menu-active';
    if ( writemag_get_option('center_primary_menu') ) {
        $classes[] = 'writemag-primary-menu-centered';
    }

    if ( writemag_is_secondary_menu_active() ) {
        $classes[] = 'writemag-secondary-menu-active';
    } else {
        $classes[] = 'writemag-secondary-menu-inactive';
    }
    $classes[] = 'writemag-secondary-mobile-menu-active';
    if ( writemag_get_option('center_secondary_menu') ) {
        $classes[] = 'writemag-secondary-menu-centered';
    }

    if ( 'before-header' === writemag_secondary_menu_location() ) {
        $classes[] = 'writemag-secondary-menu-before-header';
    } elseif ( 'after-header' === writemag_secondary_menu_location() ) {
        $classes[] = 'writemag-secondary-menu-after-header';
    } elseif ( 'before-footer' === writemag_secondary_menu_location() ) {
        $classes[] = 'writemag-secondary-menu-before-footer';
    } elseif ( 'after-footer' === writemag_secondary_menu_location() ) {
        $classes[] = 'writemag-secondary-menu-after-footer';
    } else {
        $classes[] = 'writemag-secondary-menu-before-header';
    }

    if ( 'primary-menu' === writemag_social_buttons_location() ) {
        $classes[] = 'writemag-primary-social-icons';
    } else {
        $classes[] = 'writemag-secondary-social-icons';
    }

    if ( writemag_get_option('separate_taxonomies') ) {
        $classes[] = 'writemag-separate-taxonomies';
    }

    $classes[] = 'writemag-table-css-active';

    if ( writemag_get_option('no_underline_content_links') ) {
        $classes[] = 'writemag-nouc-links';
    } else {
        $classes[] = 'writemag-uc-links';
    }

    return $classes;
}
add_filter( 'body_class', 'writemag_body_classes' );


/* Posts container class */
function writemag_posts_container_class() {
    if ( 'compactview' == writemag_post_style() ) {
        $posts_container_class = 'writemag-compact-posts-container writemag-fpw-1-column';
    } else {
        $posts_container_class = 'writemag-default-posts-container';
    }
    return apply_filters( 'writemag_posts_container_class', $posts_container_class );
}