<?php
/**
* Enqueue scripts and styles
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_scripts() {
    wp_enqueue_style('writemag-maincss', get_stylesheet_uri(), array(), null);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
    wp_enqueue_style('writemag-webfont', '//fonts.googleapis.com/css?family=Domine:400,700|Oswald:400,700|Patua+One|Frank+Ruhl+Libre:400,700&amp;display=swap', array(), null);

    $writemag_primary_menu_active = false;
    if ( writemag_is_primary_menu_active() ) {
        $writemag_primary_menu_active = true;
    }
    $writemag_secondary_menu_active = false;
    if ( writemag_is_secondary_menu_active() ) {
        $writemag_secondary_menu_active = true;
    }

    $writemag_sticky_sidebar_active = true;
    if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
       $writemag_sticky_sidebar_active = false;
    }
    if ( is_404() ) {
        $writemag_sticky_sidebar_active = false;
    }
    if ( $writemag_sticky_sidebar_active ) {
        wp_enqueue_script('ResizeSensor', get_template_directory_uri() .'/assets/js/ResizeSensor.min.js', array( 'jquery' ), null, true);
        wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.min.js', array( 'jquery' ), null, true);
    }

    $writemag_fitvids_active = false;
    if ( writemag_is_fitvids_active() ) {
        $writemag_fitvids_active = true;
    }
    if ( $writemag_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), null, true);
    }

    $writemag_backtotop_active = false;
    if ( writemag_is_backtotop_active() ) {
        $writemag_backtotop_active = true;
    }

    wp_enqueue_script('writemag-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), null, true );
    wp_enqueue_script('writemag-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), null, true );
    wp_enqueue_script('writemag-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded' ), null, true);
    wp_localize_script( 'writemag-customjs', 'writemag_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $writemag_primary_menu_active,
            'secondary_menu_active' => $writemag_secondary_menu_active,
            'sticky_sidebar_active' => $writemag_sticky_sidebar_active,
            'fitvids_active' => $writemag_fitvids_active,
            'backtotop_active' => $writemag_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('writemag-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), null, true);

    wp_localize_script('writemag-html5shiv-js','writemag_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'writemag'),
    ));
}
add_action( 'wp_enqueue_scripts', 'writemag_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function writemag_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), null, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'writemag_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function writemag_block_editor_styles() {
    wp_enqueue_style( 'writemag-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), null );
}
add_action( 'enqueue_block_editor_assets', 'writemag_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function writemag_enqueue_customizer_styles() {
    wp_enqueue_style( 'writemag-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), null );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
}
add_action( 'customize_controls_enqueue_scripts', 'writemag_enqueue_customizer_styles' );