<?php
/**
* Header Functions
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function writemag_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'writemag_pingback_header' );

// Get custom-logo URL
function writemag_custom_logo() {
    if ( ! has_custom_logo() ) {return;}
    $writemag_custom_logo_id = get_theme_mod( 'custom_logo' );
    $writemag_logo = wp_get_attachment_image_src( $writemag_custom_logo_id , 'full' );
    $writemag_logo_src = $writemag_logo[0];
    return apply_filters( 'writemag_custom_logo', $writemag_logo_src );
}

// Site Title
function writemag_site_title() {
    if ( is_front_page() && is_home() ) { ?>
            <h1 class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_home() ) { ?>
            <h1 class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_singular() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_category() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_tag() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_author() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_archive() && !is_category() && !is_tag() && !is_author() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_search() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_404() ) { ?>
            <p class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } else { ?>
            <h1 class="writemag-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(writemag_get_option('hide_tagline')) ) { ?><p class="writemag-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php }
}

function writemag_header_image_destination() {
    $url = home_url( '/' );

    if ( writemag_get_option('header_image_destination') ) {
        $url = writemag_get_option('header_image_destination');
    }

    return apply_filters( 'writemag_header_image_destination', $url );
}

function writemag_header_image_alt_text() {
    $header_image_alt_text = get_bloginfo( 'name' );

    if ( writemag_get_option('header_image_alt_text') ) {
        $header_image_alt_text = writemag_get_option('header_image_alt_text');
    }

    return apply_filters( 'writemag_header_image_alt_text', $header_image_alt_text );
}

function writemag_header_image_markup() {
    if ( get_header_image() ) {
        if ( writemag_get_option('remove_header_image_link') ) {
            the_header_image_tag( array( 'class' => 'writemag-header-img', 'alt' => esc_attr( writemag_header_image_alt_text() ) ) );
        } else { ?>
            <a href="<?php echo esc_url( writemag_header_image_destination() ); ?>" rel="home" class="writemag-header-img-link"><?php the_header_image_tag( array( 'class' => 'writemag-header-img', 'alt' => esc_attr( writemag_header_image_alt_text() ) ) ); ?></a>
        <?php }
    }
}

function writemag_header_image_details() {
    $header_image_custom_title = '';
    if ( writemag_get_option('header_image_custom_title') ) {
        $header_image_custom_title = writemag_get_option('header_image_custom_title');
    }

    $header_image_custom_description = '';
    if ( writemag_get_option('header_image_custom_description') ) {
        $header_image_custom_description = writemag_get_option('header_image_custom_description');
    }

    if ( !(writemag_get_option('hide_header_image_details')) ) { ?>
    <div class="writemag-header-image-info">
    <div class="writemag-header-image-info-inside">
    <?php if ( $header_image_custom_title ) { ?>
        <p class="writemag-header-image-site-title writemag-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_title) ) ); ?></p>
    <?php } else { ?>
        <p class="writemag-header-image-site-title writemag-header-image-block"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
    <?php } ?>

    <?php if ( $header_image_custom_description ) { ?>
        <?php if ( !(writemag_get_option('hide_header_image_description')) ) { ?><?php if ( $header_image_custom_description ) { ?><p class="writemag-header-image-site-description writemag-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_description) ) ); ?></p><?php } ?><?php } ?>
    <?php } else { ?>
        <?php if ( !(writemag_get_option('hide_header_image_description')) ) { ?><p class="writemag-header-image-site-description writemag-header-image-block"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } ?>
    </div>
    </div>
    <?php }
}

function writemag_header_image_wrapper() { ?>
    <div class="writemag-header-image writemag-clearfix">
    <?php writemag_header_image_markup(); ?>
    <?php writemag_header_image_details(); ?>
    </div>
    <?php
}

function writemag_header_image() {
    if ( writemag_get_option('hide_header_image') ) { return; }
    if ( get_header_image() ) {
        writemag_header_image_wrapper();
    }
}