<?php
/**
* Layout Functions
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_post_style() {
   $post_style = 'compactview';
    if ( writemag_get_option('post_style') ) {
        $post_style = writemag_get_option('post_style');
    }
    return apply_filters( 'writemag_post_style', $post_style );
}

function writemag_hide_footer_widgets() {
    $hide_footer_widgets = false;

    if ( writemag_get_option('hide_footer_widgets') ) {
        $hide_footer_widgets = true;
    }

    return apply_filters( 'writemag_hide_footer_widgets', $hide_footer_widgets );
}

function writemag_is_primary_menu_active() {
    $primary_menu_active = true;

    if ( writemag_get_option('disable_primary_menu') ) {
        $primary_menu_active = false;
    }

    return apply_filters( 'writemag_is_primary_menu_active', $primary_menu_active );
}

function writemag_is_secondary_menu_active() {
    $secondary_menu_active = true;

    if ( writemag_get_option('disable_secondary_menu') ) {
        $secondary_menu_active = false;
    }

    return apply_filters( 'writemag_is_secondary_menu_active', $secondary_menu_active );
}

function writemag_is_header_content_active() {
    $header_content_active = true;

    if ( writemag_get_option('hide_header_content') ) {
        $header_content_active = false;
    }

    return apply_filters( 'writemag_is_header_content_active', $header_content_active );
}

function writemag_social_buttons_location() {
    $social_buttons_location = 'secondary-menu';

    if ( writemag_get_option('social_buttons_location') ) {
        $social_buttons_location = writemag_get_option('social_buttons_location');
    }

   return apply_filters( 'writemag_social_buttons_location', $social_buttons_location );
}

function writemag_is_social_buttons_active() {
    $social_buttons_active = true;

    if ( writemag_get_option('hide_social_buttons') ) {
        $social_buttons_active = false;
    }

    return apply_filters( 'writemag_is_social_buttons_active', $social_buttons_active );
}

function writemag_is_fitvids_active() {
    $fitvids_active = true;

    if ( writemag_get_option('disable_fitvids') ) {
        $fitvids_active = false;
    }

    return apply_filters( 'writemag_is_fitvids_active', $fitvids_active );
}

function writemag_is_backtotop_active() {
    $backtotop_active = true;

    if ( writemag_get_option('disable_backtotop') ) {
        $backtotop_active = false;
    }

    return apply_filters( 'writemag_is_backtotop_active', $backtotop_active );
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function writemag_content_width() {
    $content_width = 597;

    if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
       $content_width = 1218;
    }

    if ( is_404() ) {
        $content_width = 1218;
    }

    $GLOBALS['content_width'] = apply_filters( 'writemag_content_width', $content_width ); /* phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound */
}
add_action( 'template_redirect', 'writemag_content_width', 0 );