<?php
/**
* Menu Functions
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

// Get our wp_nav_menu() fallback, wp_page_menu(), to show a "Home" link as the first item
function writemag_page_menu_args( $args ) {
    $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'writemag_page_menu_args' );

function writemag_primary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'writemag' );
    if ( writemag_get_option('primary_menu_text') ) {
        $menu_text = writemag_get_option('primary_menu_text');
    }
   return apply_filters( 'writemag_primary_menu_text', $menu_text );
}

function writemag_secondary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'writemag' );
    if ( writemag_get_option('secondary_menu_text') ) {
        $menu_text = writemag_get_option('secondary_menu_text');
    }
   return apply_filters( 'writemag_secondary_menu_text', $menu_text );
}

function writemag_primary_fallback_menu() {
    wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'writemag-menu-primary-navigation',
        'menu_class'   => 'writemag-primary-nav-menu writemag-menu-primary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function writemag_secondary_fallback_menu() {
   wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'writemag-menu-secondary-navigation',
        'menu_class'   => 'writemag-secondary-nav-menu writemag-menu-secondary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function writemag_primary_menu_area() {
if ( (writemag_is_primary_menu_active()) || (('primary-menu' === writemag_social_buttons_location()) && writemag_is_social_buttons_active()) ) { ?>
<div class="writemag-container writemag-primary-menu-container writemag-clearfix">
<div class="writemag-primary-menu-container-inside writemag-clearfix">
<nav class="writemag-nav-primary" id="writemag-primary-navigation" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'writemag' ); ?>">
<div class="writemag-outer-wrapper">

<?php if ( writemag_is_primary_menu_active() ) { ?>
<button class="writemag-primary-responsive-menu-icon" aria-controls="writemag-menu-primary-navigation" aria-expanded="false"><?php echo esc_html( writemag_primary_menu_text() ); ?></button>
<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'writemag-menu-primary-navigation', 'menu_class' => 'writemag-primary-nav-menu writemag-menu-primary writemag-clearfix', 'fallback_cb' => 'writemag_primary_fallback_menu', 'container' => '', ) ); ?>
<?php } ?>

<?php if ( 'primary-menu' === writemag_social_buttons_location() ) { ?>
    <?php if ( writemag_is_social_buttons_active() ) { ?>
        <?php writemag_header_social_buttons(); ?>
        <div id="writemag-search-overlay-wrap" class="writemag-search-overlay">
          <div class="writemag-search-overlay-content">
            <?php get_search_form(); ?>
          </div>
          <button class="writemag-search-closebtn" aria-label="<?php esc_attr_e( 'Close Search', 'writemag' ); ?>" title="<?php esc_attr_e('Close Search','writemag'); ?>">&#xD7;</button>
        </div>
    <?php } ?>
<?php } ?>

</div>
</nav>
</div>
</div>
<?php }
}

function writemag_secondary_menu_location() {
    $secondary_menu_location = 'before-header';
    if ( writemag_get_option('secondary_menu_location') ) {
        $secondary_menu_location = writemag_get_option('secondary_menu_location');
    }
    return apply_filters( 'writemag_secondary_menu_location', $secondary_menu_location );
}

function writemag_secondary_menu_area() {
if ( (writemag_is_secondary_menu_active()) || (('secondary-menu' === writemag_social_buttons_location()) && writemag_is_social_buttons_active()) ) { ?>
<div class="writemag-container writemag-secondary-menu-container writemag-clearfix">
<div class="writemag-secondary-menu-container-inside writemag-clearfix">
<nav class="writemag-nav-secondary" id="writemag-secondary-navigation" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" role="navigation" aria-label="<?php esc_attr_e( 'Secondary Menu', 'writemag' ); ?>">
<div class="writemag-outer-wrapper">

<?php if ( writemag_is_secondary_menu_active() ) { ?>
<button class="writemag-secondary-responsive-menu-icon" aria-controls="writemag-menu-secondary-navigation" aria-expanded="false"><?php echo esc_html( writemag_secondary_menu_text() ); ?></button>
<?php wp_nav_menu( array( 'theme_location' => 'secondary', 'menu_id' => 'writemag-menu-secondary-navigation', 'menu_class' => 'writemag-secondary-nav-menu writemag-menu-secondary writemag-clearfix', 'fallback_cb' => 'writemag_secondary_fallback_menu', 'container' => '', ) ); ?>
<?php } ?>

<?php if ( 'secondary-menu' === writemag_social_buttons_location() ) { ?>
    <?php if ( writemag_is_social_buttons_active() ) { ?>
        <?php writemag_header_social_buttons(); ?>
        <div id="writemag-search-overlay-wrap" class="writemag-search-overlay">
          <div class="writemag-search-overlay-content">
            <?php get_search_form(); ?>
          </div>
          <button class="writemag-search-closebtn" aria-label="<?php esc_attr_e( 'Close Search', 'writemag' ); ?>" title="<?php esc_attr_e('Close Search','writemag'); ?>">&#xD7;</button>
        </div>
    <?php } ?>
<?php } ?>

</div>
</nav>
</div>
</div>
<?php }
}