<?php
/**
* Post meta functions
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'writemag_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function writemag_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'writemag' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="writemag-tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'writemag' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;

if ( ! function_exists( 'writemag_compactview_header_postmeta' ) ) :
function writemag_compactview_header_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(writemag_get_option('hide_post_author_home')) || !(writemag_get_option('hide_posted_date_home')) || !(writemag_get_option('hide_comments_link_home')) ) { ?>
    <div class="writemag-compact-post-header">
    <?php if ( !(writemag_get_option('hide_post_author_home')) ) { ?><span class="writemag-compact-post-header-author writemag-compact-post-header-meta"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_posted_date_home')) ) { ?><span class="writemag-compact-post-header-date writemag-compact-post-header-meta"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html(get_the_date()); ?></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_comments_link_home')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="writemag-compact-post-header-comment writemag-compact-post-header-meta"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comments<span class="writemag-sr-only"> on %s</span>', 'writemag' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;

if ( ! function_exists( 'writemag_single_cats' ) ) :
function writemag_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'writemag' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<div class="writemag-entry-meta-single writemag-entry-meta-single-top"><span class="writemag-entry-meta-single-cats"><i class="far fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="writemag-sr-only">Posted in </span>%1$s', 'writemag' ) . '</span></div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;

if ( ! function_exists( 'writemag_single_postmeta' ) ) :
function writemag_single_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(writemag_get_option('hide_post_author')) || !(writemag_get_option('hide_posted_date')) || !(writemag_get_option('hide_comments_link')) || !(writemag_get_option('hide_post_edit')) ) { ?>
    <div class="writemag-entry-meta-single">
    <?php if ( !(writemag_get_option('hide_post_author')) ) { ?><span class="writemag-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_posted_date')) ) { ?><span class="writemag-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_comments_link')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="writemag-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="writemag-sr-only"> on %s</span>', 'writemag' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( !(writemag_get_option('hide_post_edit')) ) { ?><?php edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="writemag-sr-only"> %s</span>', 'writemag' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="edit-link">&nbsp;&nbsp;<i class="far fa-edit" aria-hidden="true"></i> ', '</span>' ); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;

if ( ! function_exists( 'writemag_page_postmeta' ) ) :
function writemag_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(writemag_get_option('hide_page_author')) || !(writemag_get_option('hide_page_date')) || !(writemag_get_option('hide_page_comments')) ) { ?>
    <?php if ( !((is_front_page()) && (writemag_get_option('hide_static_page_meta'))) ) { ?>
    <div class="writemag-entry-meta-single writemag-entry-meta-page">
    <?php if ( !(writemag_get_option('hide_page_author')) ) { ?><span class="writemag-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_page_date')) ) { ?><span class="writemag-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html(get_the_date()); ?></span><?php } ?>
    <?php if ( !(writemag_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="writemag-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="writemag-sr-only"> on %s</span>', 'writemag' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
    <?php } ?>
<?php }
endif;

function writemag_post_cat_links_text() {
    if ( writemag_is_option_set('cat_links_text') ) {
        $cat_links_text = writemag_get_option('cat_links_text');
    } else {
        $cat_links_text = esc_html__( 'Posted in:', 'writemag' );
    }
    return apply_filters( 'writemag_post_cat_links_text', $cat_links_text );
}

function writemag_post_tag_links_text() {
    if ( writemag_is_option_set('tag_links_text') ) {
        $tag_links_text = writemag_get_option('tag_links_text');
    } else {
        $tag_links_text = esc_html__( 'Tagged:', 'writemag' );
    }
    return apply_filters( 'writemag_post_tag_links_text', $tag_links_text );
}

if ( ! function_exists( 'writemag_compactview_footer_postmeta' ) ) :
 /**
  * Prints HTML with meta information for the categories, tags and comments.
  */
function writemag_compactview_footer_postmeta() {
    global $post; ?>
    <?php if ( (!(writemag_get_option('hide_post_categories_home')) && has_category() && ('post' == get_post_type())) || (!(writemag_get_option('hide_post_tags_home')) && has_tag() && ('post' == get_post_type())) ) { ?>
    <div class="writemag-compact-post-footer">
    <div class="writemag-compact-post-footer-inside">
    <?php
    if ( !(writemag_get_option('hide_post_categories_home')) && has_category() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list( esc_html__( ', ', 'writemag' ) );
            if ( $categories_list ) { ?>
                <span class="writemag-compact-post-footer-cat-links writemag-compact-post-footer-meta"><i class="fas fa-folder-open"></i>&nbsp;<?php if(writemag_post_cat_links_text()) { ?><span class="writemag-compact-post-footer-meta-text"><?php echo wp_kses_post(writemag_post_cat_links_text()); ?>&nbsp;</span><?php } ?><?php echo wp_kses_post( $categories_list ); ?></span>
            <?php }
        }
    }

    if ( !(writemag_get_option('hide_post_tags_home')) && has_tag() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'writemag' ) );
            if ( $tags_list ) { ?>
                <span class="writemag-compact-post-footer-tags-links writemag-compact-post-footer-meta"><i class="fas fa-tags"></i>&nbsp;<?php if(writemag_post_tag_links_text()) { ?><span class="writemag-compact-post-footer-meta-text"><?php echo wp_kses_post(writemag_post_tag_links_text()); ?>&nbsp;</span><?php } ?><?php echo wp_kses_post( $tags_list ); ?></span>
            <?php }
        }
    }
    ?>
    </div>
    </div>
    <?php } ?>
    <?php
}
endif;