<?php
/**
* Post share buttons
*
* @package WriteMag WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function writemag_share_text() {
    $sharetext = esc_html__( 'Share:', 'writemag' );
    if ( writemag_get_option('hide_share_text') ) {return;}
    if ( writemag_get_option('share_text') ) {
        $sharetext = writemag_get_option('share_text');
    }
    return apply_filters( 'writemag_share_text', $sharetext );
}

function writemag_share_text_home() {
    $sharetext = esc_html__( 'Share:', 'writemag' );
    if ( writemag_get_option('hide_share_text_home') ) {return;}
    if ( writemag_get_option('share_text_home') ) {
        $sharetext = writemag_get_option('share_text_home');
    }
    return apply_filters( 'writemag_share_text_home', $sharetext );
}

function writemag_social_sharing_buttons() {

        global $post;

        // Get current page URL 
        $posturl = rawurlencode(get_permalink($post->ID));

        // Get current page title
        $posttitle = rawurlencode(the_title_attribute('echo=0'));

        // Construct sharing URL without using any script
        $x_url = 'https://x.com/intent/post?text='.$posttitle.'&amp;url='.$posturl;
        $facebook_url = 'https://www.facebook.com/sharer.php?u='.$posturl;
        $linkedin_url = 'https://www.linkedin.com/shareArticle?mini=true&amp;title='.$posttitle.'&amp;url='.$posturl;

        $postthumb = '';
        $postthumb_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false );
        $postthumb = isset($postthumb_attributes[0]) ? $postthumb_attributes[0] : '';

        if(!empty($postthumb)) {
            $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.$posturl.'&amp;media='.$postthumb.'&amp;description='.$posttitle;
        }

        $socialcontent = '<div class="writemag-share-buttons writemag-clearfix"><span class="writemag-share-text">'.esc_html(writemag_share_text()).' </span>';
        if ( !(writemag_get_option('hide_share_twitter')) ) {
            $socialcontent .= '<a class="writemag-share-buttons-twitter" href="'.esc_url($x_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on X', 'writemag').'"><i class="fab fa-x-twitter" aria-hidden="true"></i>'.esc_html__('X', 'writemag').'</a>';
        }
        if ( !(writemag_get_option('hide_share_facebook')) ) {
            $socialcontent .= '<a class="writemag-share-buttons-facebook" href="'.esc_url($facebook_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Facebook', 'writemag').'"><i class="fab fa-facebook-f" aria-hidden="true"></i>'.esc_html__('Facebook', 'writemag').'</a>';
        }
        if ( !(writemag_get_option('hide_share_pinterest')) && !(empty($postthumb)) ) {
            $socialcontent .= '<a class="writemag-share-buttons-pinterest" href="'.esc_url($pinterest_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Pinterest', 'writemag').'"><i class="fab fa-pinterest" aria-hidden="true"></i>'.esc_html__('Pinterest', 'writemag').'</a>';
        }
        if ( !(writemag_get_option('hide_share_linkedin')) ) {
            $socialcontent .= '<a class="writemag-share-buttons-linkedin" href="'.esc_url($linkedin_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Linkedin', 'writemag').'"><i class="fab fa-linkedin-in" aria-hidden="true"></i>'.esc_html__('Linkedin', 'writemag').'</a>';
        }
        $socialcontent .= '</div>';

        return apply_filters( 'writemag_social_sharing_buttons', $socialcontent );

}

function writemag_small_share_buttons() {

        global $post;

        // Get current page URL 
        $posturl = rawurlencode(get_permalink($post->ID));

        // Get current page title
        $posttitle = rawurlencode(the_title_attribute('echo=0'));

        // Construct sharing URL without using any script
        $x_url = 'https://x.com/intent/post?text='.$posttitle.'&amp;url='.$posturl;
        $facebook_url = 'https://www.facebook.com/sharer.php?u='.$posturl;
        $linkedin_url = 'https://www.linkedin.com/shareArticle?mini=true&amp;title='.$posttitle.'&amp;url='.$posturl;

        $postthumb = '';
        $postthumb_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false );
        $postthumb = isset($postthumb_attributes[0]) ? $postthumb_attributes[0] : '';

        if(!empty($postthumb)) {
            $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.$posturl.'&amp;media='.$postthumb.'&amp;description='.$posttitle;
        }

        $socialcontent = '<div class="writemag-small-share-buttons writemag-grid-post-block writemag-clearfix"><div class="writemag-small-share-buttons-inside writemag-clearfix"><span class="writemag-small-share-text">'.wp_kses_post(writemag_share_text_home()).' </span>';
        if ( !(writemag_get_option('hide_share_twitter_home')) ) {
            $socialcontent .= '<a class="writemag-small-share-buttons-twitter" href="'.esc_url($x_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on X', 'writemag').' : '.the_title_attribute('echo=0').'"><i class="fab fa-x-twitter" aria-hidden="true"></i>'.esc_html__('X', 'writemag').'<span class="writemag-sr-only"> : '.esc_html( get_the_title() ).'</span></a>';
        }
        if ( !(writemag_get_option('hide_share_facebook_home')) ) {
            $socialcontent .= '<a class="writemag-small-share-buttons-facebook" href="'.esc_url($facebook_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Facebook', 'writemag').' : '.the_title_attribute('echo=0').'"><i class="fab fa-facebook-f" aria-hidden="true"></i>'.esc_html__('Facebook', 'writemag').'<span class="writemag-sr-only"> : '.esc_html( get_the_title() ).'</span></a>';
        }
        if ( !(writemag_get_option('hide_share_pinterest_home')) && !(empty($postthumb)) ) {
            $socialcontent .= '<a class="writemag-small-share-buttons-pinterest" href="'.esc_url($pinterest_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Pinterest', 'writemag').' : '.the_title_attribute('echo=0').'"><i class="fab fa-pinterest" aria-hidden="true"></i>'.esc_html__('Pinterest', 'writemag').'<span class="writemag-sr-only"> : '.esc_html( get_the_title() ).'</span></a>';
        }
        if ( !(writemag_get_option('hide_share_linkedin_home')) ) {
            $socialcontent .= '<a class="writemag-small-share-buttons-linkedin" href="'.esc_url($linkedin_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Linkedin', 'writemag').' : '.the_title_attribute('echo=0').'"><i class="fab fa-linkedin-in" aria-hidden="true"></i>'.esc_html__('Linkedin', 'writemag').'<span class="writemag-sr-only"> : '.esc_html( get_the_title() ).'</span></a>';
        }
        $socialcontent .= '</div></div>';

        return apply_filters( 'writemag_small_share_buttons', $socialcontent );

}